@@ -42,8 +42,8 @@ class Endereco(core.models.Log, core.models.EnderecoComplementoLog):
 class Cartao(core.models.Log):
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
     cliente_token = models.CharField(max_length=200, null=True)
-    cartao_token = models.CharField(max_length=200, null=True)
     cartao_id = models.CharField(max_length=50, null=True)
+    password = models.CharField(max_length=50, null=True)
 
     primeiros_6 = models.CharField(max_length=6, null=True)
     ultimos_4 = models.CharField(max_length=4, null=True)
@@ -100,7 +100,7 @@ class CartaoBandeiraParcela(core.models.Log):
 class Termo(core.models.Log):
     nome = models.CharField(max_length=200, primary_key=True)
     nome_descritivo = models.CharField(max_length=200, null=True)
-    nome_html = models.CharField(max_length=200, null=True)
+    nome_html = models.CharField(max_length=500, null=True)
     versao = models.CharField(max_length=50, null=True)
     termo_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)
     descricao = models.TextField(null=True)
